# Databricks jobs bundle

Create Databricks jobs from YAML templates.

Provides console commands to automate jobs creation, deletion, ...

## Installation

Install the bundle via Poetry:

```
$ poetry add jobs-bundle
```
